@@ -30,7 +30,7 @@ class Populate(
 
     def populate_from_dict(self, datum: dict, skipped_keys: List[str] = []):
         self.check_not_soft_deleted()
-        columns = self.__class__.__table__.columns._data
+        columns = self.__mapper__.columns
         columns_keys_to_populate = self._get_column_keys_to_populate(
             set(columns.keys()), datum, skipped_keys)
         for key in columns_keys_to_populate:
@@ -52,7 +52,14 @@ class Populate(
             else:
                 setattr(self, key, value)
 
-        for key in self.__mapper__.relationships.keys():
+        for (key, relationship) in self.__mapper__.relationships.items():
+            if key in datum:
+                model = relationship.mapper.class_
+                value = self._get_model_instance(datum[key], model)
+                if value:
+                    setattr(self, key, value)
+
+        for key in self.__mapper__.synonyms.keys():
             if key in datum:
                 setattr(self, key, datum[key])
 
@@ -64,6 +71,19 @@ class Populate(
         keys_to_populate = column_keys.intersection(allowed_columns_to_update)
         return keys_to_populate
 
+    @staticmethod
+    def _get_model_instance(value, model):
+        if not isinstance(value, model):
+            if hasattr(value, 'items'):
+                if 'id' in value:
+                    model_instance = model.query.get(dehumanize(value['id']))
+                    model_instance.populate_from_dict(value)
+                    return model_instance
+                return model(**value)
+            elif hasattr(value, '__iter__'):
+                return list(map(lambda obj: Populate._get_model_instance(obj, model), value))
+        return value
+
     def _try_to_set_attribute_with_deserialized_datetime(self, col, key, value):
         try:
             datetime_value = _deserialize_datetime(key, value)
@@ -90,11 +110,13 @@ class Populate(
             error.add_error(col.name, "Invalid value for {} ({}): '{}'".format(key, expected_format, value))
             raise error
 
+
 def _dehumanize_if_needed(column, value: Any) -> Any:
     if _is_human_id_column(column):
         return dehumanize(value)
     return value
 
+
 def _deserialize_datetime(key, value):
     if value is None:
         return None
@@ -111,6 +133,7 @@ def _deserialize_datetime(key, value):
 
     return datetime_value
 
+
 def _is_human_id_column(column: Column) -> bool:
     if column is not None:
         return (column.key == 'id' or column.key.endswith('Id')) and isinstance(column.type, (BigInteger, Integer))
